% ODCget.m is a Matlab script file that can obtain datas with different request numbers from URLs using loaddods.
% The datas obtained from URLs will be stored in base workspace with request number Rx_
% Before running ODCget in Matlab, it is necessary to run ODC Client to get URL(s) first.
% User can initialize the request number by setup a variable called ODCrequest in base workspace. If no initialized
% request number is given, it will be default to 1.
% echooff is an input augument to echo off display with format of ODCget('echooff')
% This program reqires Matlab version 6 or higher and Java 1.4


function ODCget(argin1,argin2)


global request matlabURL count

if nargin~=2
   
    callbackstring='ODCget(''sendvar'', ODCrequest)';
    
    try
        evalin('base',callbackstring);
    catch
        if isempty(count)
            request =1;
            count = 1;
        end
        
    end
    

% Check for Matlab version
ver = version;
verMajor = str2num(ver(1));

if verMajor <= 5
    disp(' This program requires Matlab version 6 or higher');
    return;
else  % Check if Java is enabled
    version -java;
    if strcmp(ans,'Java is not enabled') ~=0
        disp('This program required Java enabled');
        return;
    end
end
end
% test('clear') will clear all the variables in workspace and start to get variables with request number R1
echoon = 1;
if nargin == 1
    if argin1 == 'echooff'
        echoon = 0;
    end
elseif nargin == 2
    if argin1 == 'sendvar'
        request = argin2;
        return;
    end
end

try
    % create instance for java class of opendap.clients.odc.IPSClient.ODCclient
    ODCObject = opendap.clients.odc.IPSClient.ODCclient;  

catch
    disp('Undefined Java class of opendap.clients.odc.IPSClient.ODCclient');
    disp('or need to check classpath.txt file for Java class path');
end

ODCObject.matlab_vLoadURLs;
HadError = ODCObject.matlab_hasError;
if HadError
    javaError = ODCObject.matlab_getError;
    
    disp(char(javaError))
    
else
    if isempty(request)  % if first time call test from workspace
        request = 1;
    end
        
    URL_count = ODCObject.matlab_getURLCount;
    for i = request:URL_count+request-1
        javaURL = ODCObject.matlab_getURL(i-request+1);
        matlabURL = char(javaURL);
        if echoon
            disp(sprintf(' Reading: %s', matlabURL))
        end
        loaddods(matlabURL)
        acqno = sprintf('R%i_',i);
        if echoon
            disp(sprintf('Creating Variables in %s',acqno))
        end
        varname = loaddods('-s',matlabURL); % obtain variable names for this request
        urlname = strcat(acqno,'URL');
        
        evalin('base', 'clear matlabURL; global matlabURL')       
        evalin('base', [urlname ' = matlabURL; clear matlabURL'])  % put Rx_URL in workspace
                
        for j = 1:size(varname,1)
            var_j = deblank(varname(j,:));
            var = strcat(acqno,var_j);
            callbackstring = sprintf('%s=%s;',var,var_j); % Store the variables obtained from urls with request No, say Rx_
            evalin('base',callbackstring);
            clearstring = sprintf('clear %s;', var_j);
            evalin('base',clearstring);  % clear variables obtained from urls without request no in workspace
        end
    end
    request = request + URL_count;  % update request No      
    requestname = 'ODCrequest';
    evalin('base', 'clear request; global request')
    evalin('base', [requestname '= request; clear request'])  % update ODCrequest in base workspace
end
